var indexSectionsWithContent =
{
  0: "0123456789:abcdefghiklmnoprstuvwxy",
  1: "clmst",
  2: "abcdegilopsuw",
  3: "acdefgiklmnprsuv",
  4: "s",
  5: "s",
  6: "abcefhiklmpstw",
  7: "0123456789:abcdefghiklmnoprstuvwxy"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "functions",
  3: "variables",
  4: "typedefs",
  5: "enumvalues",
  6: "groups",
  7: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Data Structures",
  2: "Functions",
  3: "Variables",
  4: "Typedefs",
  5: "Enumerator",
  6: "Modules",
  7: "Pages"
};

